Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(664)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/suggestions/MostVisitedSites.java

Issue 2790463003: ntp_tiles: Cleanup enum names (Closed)
Patch Set: add back histogram enums Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/android/java/src/org/chromium/chrome/browser/suggestions/MostVisitedSitesBridge.java » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/android/java/src/org/chromium/chrome/browser/suggestions/MostVisitedSites.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/suggestions/MostVisitedSites.java b/chrome/android/java/src/org/chromium/chrome/browser/suggestions/MostVisitedSites.java
index 0e392dd048fa7ed5e5371e96c717c5acd4bf321b..ba66428a7e39c19a6881086d2feb26bd67464b1d 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/suggestions/MostVisitedSites.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/suggestions/MostVisitedSites.java
@@ -5,8 +5,6 @@
package org.chromium.chrome.browser.suggestions;
import org.chromium.base.annotations.CalledByNative;
-import org.chromium.chrome.browser.ntp.MostVisitedTileType;
-import org.chromium.chrome.browser.ntp.NTPTileSource;
/**
* Methods to provide most recent urls, titles and thumbnails.
@@ -26,7 +24,7 @@ interface MostVisitedSites {
* visited URLs).
* @param whitelistIconPaths The paths to the icon image files for whitelisted tiles, empty
* strings otherwise.
- * @param sources For each tile, the {@code NTPTileSource} that generated the tile.
+ * @param sources For each tile, the {@code TileSource} that generated the tile.
*/
@CalledByNative("Observer")
void onMostVisitedURLsAvailable(
@@ -68,9 +66,9 @@ interface MostVisitedSites {
/**
* Records metrics about an impression, including the sources (local, server, ...) and visual
* types of the tiles that are shown.
* @param tileTypes An array of values from MostVisitedTileType indicating the type of each
* tile that's currently showing.
* @param sources An array of values from NTPTileSource indicating the source of each tile
* that's currently showing.
* @param tileUrls An array of strings indicating the URL of each tile.
*/
@@ -79,10 +77,9 @@ interface MostVisitedSites {
/**
* Records the opening of a Most Visited Item.
* @param index The index of the item that was opened.
* @param type The visual type of the item as defined in {@code MostVisitedTileType}.
* @param source The {@code NTPTileSource} that generated this item.
*/
- void recordOpenedMostVisitedItem(int index,
- @MostVisitedTileType.MostVisitedTileTypeEnum int type,
- @NTPTileSource.NTPTileSourceEnum int source);
+ void recordOpenedMostVisitedItem(int index, @TileVisualType.TileVisualTypeEnum int type,
+ @TileSource.TileSourceEnum int source);
}
« no previous file with comments | « no previous file | chrome/android/java/src/org/chromium/chrome/browser/suggestions/MostVisitedSitesBridge.java » ('j') | no next file with comments »
@@ -68,9 +66,9 @@ interface MostVisitedSites {
* Records metrics about an impression, including the sources (local, server, ...) and visual
* types of the tiles that are shown.
- * @param tileTypes An array of values from MostVisitedTileType indicating the type of each
+ * @param tileTypes An array of values from {@link TileVisualType} indicating the type of each
* tile that's currently showing.
@@ -68,9 +66,9 @@ interface MostVisitedSites {
* tile that's currently showing.
- * @param sources An array of values from NTPTileSource indicating the source of each tile
+ * @param sources An array of values from {@link TileSource} indicating the source of each tile
* that's currently showing.
* @param tileUrls An array of strings indicating the URL of each tile.
@@ -79,10 +77,9 @@ interface MostVisitedSites {
* Records the opening of a Most Visited Item.
* @param index The index of the item that was opened.
- * @param type The visual type of the item as defined in {@code MostVisitedTileType}.
- * @param source The {@code NTPTileSource} that generated this item.
+ * @param type The visual type of the item as defined in {@link TileVisualType}.
+ * @param source The {@link TileSource} that generated this item.
*/

Powered by Google App Engine
This is Rietveld 408576698